@@ -1,6 +1,6 @@
-from FilesOp.File import File
+from .File import File
 
 __author__ = """KingKaitoKid"""
 __email__ = 'djstrix@me.com'
-__version__ = '1.0.5'
+__version__ = '1.0.7'
 name = "FilesOp"
\ No newline at end of file
